pub trait RenderTimestamp:
MzTimestamp
+ Default
+ Refines<Timestamp> {
// Required methods
fn system_time(&mut self) -> &mut Timestamp;
fn system_delay(delay: Timestamp) -> <Self as Timestamp>::Summary;
fn event_time(&self) -> Timestamp;
fn event_time_mut(&mut self) -> &mut Timestamp;
fn event_delay(delay: Timestamp) -> <Self as Timestamp>::Summary;
fn step_back(&self) -> Self;
}Expand description
A timestamp type that can be used for operations within MZ’s dataflow layer.
Required Methods
Sourcefn system_time(&mut self) -> &mut Timestamp
fn system_time(&mut self) -> &mut Timestamp
The system timestamp component of the timestamp.
This is useful for manipulating the system time, as when delaying updates for subsequent cancellation, as with monotonic reduction.
Sourcefn system_delay(delay: Timestamp) -> <Self as Timestamp>::Summary
fn system_delay(delay: Timestamp) -> <Self as Timestamp>::Summary
Effects a system delay in terms of the timestamp summary.
Sourcefn event_time(&self) -> Timestamp
fn event_time(&self) -> Timestamp
The event timestamp component of the timestamp.
Sourcefn event_time_mut(&mut self) -> &mut Timestamp
fn event_time_mut(&mut self) -> &mut Timestamp
The event timestamp component of the timestamp, as a mutable reference.
Sourcefn event_delay(delay: Timestamp) -> <Self as Timestamp>::Summary
fn event_delay(delay: Timestamp) -> <Self as Timestamp>::Summary
Effects an event delay in terms of the timestamp summary.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".